import QtQuick 1.1
import com.nokia.meego 1.0
import "uiconstants.js" as UiConstants

Page
{
    id: loginPage

    /* helper functions */

    function doLogin(userName, userPassword)
    { //handle login to Spotify backend
        busyIndicator.text = qsTr("Logging you in to Spotify");
        busyIndicator.running = true;
        busyIndicator.visible = true;
        //disable UI elems durin login process
        userNameInput.enabled = false;
        userPasswordInput.enabled = false;
        saveCredentialsSel.enabled = false;
        loginBtn.enabled = false;
        if(!qspotCore.login(userName,userPassword,saveCredentialsSel.checked)) //request to login for the current session
        {//login failed (due to i.e., no stored credentials)
            if(userName==="")
                pageStack.replace(loginPage);
        }
    }

    PageHeader
    {
        id: loginPageHeader
        displayComboIndicator: false
        text: "QSpot"
        anchors.left: parent.left
        anchors.top: parent.top
    }


    TextField
    {
        id: userNameInput
        inputMethodHints: Qt.ImhNoAutoUppercase | Qt.ImhNoPredictiveText
        font.family: UiConstants.DEFAULT_FONT_FAMILY
        font.pointSize: UiConstants.DEFAULT_TEXT_POINTSIZE
        width: parent.width
        height: 40
        placeholderText: qsTr("Username")
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.left: parent.left
        anchors.top: loginPageHeader.bottom
        anchors.topMargin: 10
    }


    TextField
    {
        id: userPasswordInput
        inputMethodHints: Qt.ImhNoAutoUppercase | Qt.ImhNoPredictiveText
        font.family: UiConstants.DEFAULT_FONT_FAMILY
        font.pointSize: UiConstants.DEFAULT_TEXT_POINTSIZE
        width: parent.width
        height: 40
        placeholderText: qsTr("Password");
        echoMode: TextInput.Password;
        anchors.top: userNameInput.bottom
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.left: parent.left
        anchors.topMargin: 10
    }

    Row
    {
        id: saveCredentialsRow
        anchors.topMargin: 10
        anchors.top: userPasswordInput.bottom
        anchors.left: userPasswordInput.left
        spacing: UiConstants.DEFAULT_SPACING

        Switch
        {
            id: saveCredentialsSel
            platformStyle: SwitchStyle {}
        }

        Label
        {
            text: qsTr("Remember me")
            height: saveCredentialsSel.height
            verticalAlignment: Text.AlignVCenter
        }
    }

    Item
    {
        id: acceptUsageTerms
        anchors.topMargin: 5
        anchors.top: saveCredentialsRow.bottom
        anchors.left: saveCredentialsRow.left
        width: parent.width
        height: acceptUsageTermsTxt.height

        Switch
        {
            id: acceptUsageTermsSel
            anchors.left: parent.left
            anchors.top: parent.top
            platformStyle: SwitchStyle {}
        }

        Label
        {
            id: acceptUsageTermsTxt
            anchors.left: acceptUsageTermsSel.right
            font.pointSize: 10
            width: (parent.width-acceptUsageTermsSel.width-UiConstants.DEFAULT_SPACING)
            anchors.leftMargin: UiConstants.DEFAULT_SPACING
            anchors.top: parent.top
            text: qsTr("I accept the <a href=\"http://www.spotify.com/legal/end-user-agreement\">Spotify Terms and Conditions and End User License Agreement</a>")
            wrapMode: Text.WordWrap
            onLinkActivated: Qt.openUrlExternally(link)
        }
    }

    Button
    {
        id: loginBtn;
        enabled: acceptUsageTermsSel.checked
        text:  qsTr("Login")
        anchors.top: acceptUsageTerms.bottom
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.topMargin: 10
        onClicked: {
            if(userNameInput.text!=="")
                doLogin(userNameInput.text,userPasswordInput.text);
        }
    }

    //signal / slot connections
    Connections
    {
        target: qspotCore

        onLoginResponse:
        {
            if(status===false) //no error flag set
            { //successful login; transfer control to main (playlists) page
                if(userNameInput.text!=="")
                    pageStack.replace(mainPage);
            }
            //re-enbable UI elems
            userNameInput.enabled =  true;
            userNameInput.text = "";
            userPasswordInput.enabled = true;
            userPasswordInput.text = "";
            saveCredentialsSel.enabled = true;
            saveCredentialsSel.checked = false;
            loginBtn.enabled = true;
        }
    }
}

