import QtQuick 1.1
import com.nokia.meego 1.0
import "uiconstants.js" as UiConstants

/* Provides the main search view, with a tabbed interface for displaying track, album and artist search results */
Page
{
    id: searchResultsPage

    property int currSortSelection: UiConstants.SORT_OPTION_POPULARITY_DESC //default sorting by popularity

    /*misc. helper functions */

    /* set page initial state */
    function resetPageState()
    {
        searchResultsTabGroup.currentTab = trackSearchResults; //set the default active tab
    }

    /* display sort ordering selection dialog */
    function showSortOptionsDialog()
    {
       searchSortOptionsDialog.selectedIndex = currSortSelection;
       searchSortOptionsDialog.open();
    }

    /* sorting options selection dialog */
    SelectionDialog    {
        id: searchSortOptionsDialog
        titleText: qsTr("Order By")
        model: ListModel{
            id: searchSortOptionsModel
            ListElement { name: "Popularity (Descending)"; value: 0}
            ListElement { name: "Track name (Ascending)"; value: 1}
            ListElement { name: "Track name (Descending)"; value: 2}
            ListElement { name: "Artist name (Ascending)"; value: 3}
            ListElement { name: "Artist name(Descending)"; value: 4}
            ListElement { name: "Album name(Ascending)"; value: 5}
            ListElement { name: "Album name (Descending)"; value: 6}
        }

        onAccepted: {
            if(selectedIndex!=currSortSelection)
            {
                currSortSelection = selectedIndex;
                if(searchResultsTabGroup.currentTab===trackSearchResults)
                {//track search results tab active; sort the track list
                    qspotCore.sortTracks(searchSortOptionsModel.get(currSortSelection).value);
                }
                else if(searchResultsTabGroup.currentTab===albumSearchResults)
                {//album search results tab active; sort the album list
                    qspotCore.sortAlbums(currSortSelection);
                }
                else if(searchResultsTabGroup.currentTab===artistSearchResults)
                {//artist search results tab active; sort the artist list
                    qspotCore.sortArtists(currSortSelection);
                }
            }
        }
    }

    /* toolbar elements for the current page */
    tools: tabBarLayout

    ToolBarLayout {
        id: tabBarLayout
        ToolIcon { iconId: "toolbar-back"; onClicked: pageStack.pop(); }

        ButtonRow {
            platformStyle: TabButtonStyle {}
            TabButton { tab: trackSearchResults; iconSource: "../images/tracks.png" }
            TabButton { tab: albumSearchResults; iconSource: "../images/album.png" }
            TabButton { tab: artistSearchResults; iconSource: "../images/people-or-artist.png" }
         }
    }

    TabGroup {

        id: searchResultsTabGroup

        currentTab: trackSearchResults

        // define the content for track results tab
        Page {

            id: trackSearchResults

            PageHeader
            {
                id: trackSearchResultsPageHeader
                text: qsTr("Track Results");
                anchors.left: parent.left
                anchors.top: parent.top

                onClicked: { //display the sorting order selection dialog
                    showSortOptionsDialog();
                }
            }

            /* list view holding the tracks returned by search operation */
            ListView
            {
                id: trackSearchResultsView
                anchors.top: trackSearchResultsPageHeader.bottom
                anchors.topMargin: 10
                anchors.bottom:  parent.bottom
                anchors.left: parent.left
                anchors.leftMargin: 5
                anchors.right: parent.right
                anchors.rightMargin: 5
                snapMode: ListView.SnapToItem
                model: qspotCore.tracksModel
                clip: true
                interactive: true
                delegate: TrackInfoDelegate
                {
                    id: trackSearchItemDelegate
                    onClicked: {
                        trackSearchResultsView.currentIndex = index; //get the index of track item clicked (activated)
                        qspotCore.enqueueActiveTracks(index); //enqueue the current (displayed) track search results (starting with track at position index)
                        queuePage.setActiveTrack(0,true);
                        pageStack.push(queuePage); //display the  Queue (Now Playing) page (i.e., push it onto the pagestack)
                    }
                }
            }
        }

        // define the content for album results tab
        Page {
            id: albumSearchResults

            PageHeader
            {
                id: albumSearchResultsPageHeader
                displayComboIndicator: false
                text: qsTr("Album Results");
                anchors.left: parent.left
                anchors.top: parent.top
            }

            /* list view holding the albums returned by search operation */
            ListView
            {
                id: albumSearchResultsView
                anchors.top: albumSearchResultsPageHeader.bottom
                anchors.topMargin: 10
                anchors.bottom:  parent.bottom
                anchors.left: parent.left
                anchors.leftMargin: 5
                anchors.right: parent.right
                anchors.rightMargin: 5
                snapMode: ListView.SnapToItem
                model: qspotCore.albumModel
                clip: true
                interactive: true
                delegate: AlbumInfoDelegate
                {
                    id: albumSearchItemDelegate
                }
            }
        }

        // define the content for artist results tab
        Page {
            id: artistSearchResults

            PageHeader
            {
                id: artistSearchResultsPageHeader
                displayComboIndicator: false
                text: qsTr("Artist Results");
                anchors.left: parent.left
                anchors.top: parent.top

            }

            /* list view holding the artists returned by search operation */
            ListView
            {
                id: artistSearchResultsView
                anchors.top: artistSearchResultsPageHeader.bottom
                anchors.topMargin: 10
                anchors.bottom:  parent.bottom
                anchors.left: parent.left
                anchors.leftMargin: 5
                anchors.right: parent.right
                anchors.rightMargin: 5
                snapMode: ListView.SnapToItem
                model: qspotCore.artistModel
                clip: true
                interactive: true
                delegate: ArtistInfoDelegate
                {
                    id: artistSearchItemDelegate
                }
            }
        }
    }


}
