import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0
import "uiconstants.js" as UiConstants

PageStackWindow
{
    id: rootWindow
    property int pageMargin: 16

    //component instances
    property variant playlistPage: TrackPage {}
    property variant searchResultsPage: SearchResultsPage {}
    property variant queuePage: QueuePage {}
    property variant mainPage: MainPage {}
    property variant loginPage: LoginPage {}
    property variant aboutDialog : AboutDialog {}


    /* common page elements */

    ToolBarLayout {
        id:commonToolBarLayout
        ToolIcon {
            iconId: "toolbar-back";
            visible: (pageStack.depth>1 ? true : false)
            onClicked:{
                pageStack.pop();
            }
        }
        ToolIcon
        {
            id: nowPlayingBtn
            visible: ((queuePage.currTrackDuration===0||pageStack.currentPage===queuePage) ? false : true) /* element should only be shown when there are active tracks in the Now Playing view (and not on Now Playing view) */
            iconSource: "../images/nowplaying-icon.png"
            onClicked:{
                queuePage.centerViewAtCurrTrack();
                pageStack.push(queuePage); //display the Now Playing (queue) page
            }
        }
        ToolIcon {
            id: prevTrackBtn
            visible: ((queuePage.currTrackDuration!==0||pageStack.currentPage===queuePage) ? true : false) /* element should only be shown when there are active tracks in the Now Playing view */
            iconId: "toolbar-mediacontrol-previous";
            onClicked:{
                qspotCore.prevTrack(); //skip to previous track in queue
            }
        }
        ToolIcon {
            id: pauseResumeBtn
            visible: ((queuePage.currTrackDuration!==0||pageStack.currentPage===queuePage) ? true : false) /* element should only be shown when there are active tracks in the Now Playing view */
            iconId: (queuePage.isPlaying ? "toolbar-mediacontrol-pause" : "toolbar-mediacontrol-play") //handle toggling between  paused / playing state
            onClicked:{
                if(!queuePage.isPlaying)
                    queuePage.isPlaying = true;
                else
                    queuePage.isPlaying = false;
                qspotCore.pauseResumePlayback(true); //pause / resume current playback
            }
        }
        ToolIcon {
            id: nextTrackBtn
            visible: ((queuePage.currTrackDuration!==0||pageStack.currentPage===queuePage) ? true : false) /* element should only be shown when there are active tracks in the Now Playing view */
            iconId: "toolbar-mediacontrol-next";
            onClicked:{
                qspotCore.nextTrack(); //skip to next track in queue
            }
        }
        ToolIcon {
            id: shuffleBtn
            visible: ((queuePage.currTrackDuration!==0||pageStack.currentPage===queuePage) ? true : false) /* element should only be shown when there are active tracks in the Now Playing view */
            iconSource: (qspotCore.shuffleOn ? "../images/shuffle-on.png" : "../images/shuffle-off.png")
            onClicked: {
                qspotCore.toggleShuffle();
            }
        }
    }

    //custom busy indicator
    CustomBusyIndicator {
        id: busyIndicator
	visible: false
    }

    /*info banner for displaying customer user notifications */
    InfoBanner {
        id: info
   }

    Dialog {//custom dialog (messagebox) for display general info message (such as e.g., error message)
        id: messageBox
 	visualParent: pageStack
  	width: parent.width
        title: Item { id: titleItem; width: parent.width; height: 10;  Text { color: "white"; text: messageBox.dialogTitle; font.pointSize: 20 ; font.family: UiConstants.DEFAULT_FONT_FAMILY; anchors.horizontalCenter: parent.horizontalCenter;}}
        content: Item { id: txtContentItem; width: parent.width; height: 100; Text { width: parent.width; wrapMode: Text.WordWrap; font.pointSize: UiConstants.DEFAULT_TEXT_POINTSIZE; font.family: UiConstants.DEFAULT_FONT_FAMILY; color: "white"; anchors.centerIn: parent; text: messageBox.textContent}}
        buttons: ButtonRow {style: ButtonStyle { } anchors.horizontalCenter: parent.horizontalCenter; Button {id: okBtn; text: qsTr("OK"); onClicked: messageBox.close();}}

        property string dialogTitle;
        property string textContent;
    }

    showStatusBar: false //fullscreen mode
    initialPage: mainPage

    Component.onCompleted:
    { //perform app initialisation
        theme.inverted = true; //set inverted theme for QSpot application
        qspotCore.initSession(); //initialise Spotify session
        //check in case auto-login is enabled; in case it is then automatically login user
        if(qspotCore.hasStoredCredentials())
        { //initiate auto-login (stored user credentials)
            loginPage.doLogin("","");
        }
        else
        {//show the login page (no stored credentials)
            pageStack.replace(loginPage);
        }
    }
}
